// Modified this from the drill guide I made to drill holes directly through
// center of the aluminum channel for the printbed. That was a temporary
// piece, but this is designed to go in the back of the printbed and provide
// a place to wire tie the heater and thermistor cables for strain relief.
// I think the press fit is likely to be good enough, but I can always add
// some epoxy if press fit doesn't work well.

// Dimensions for aluminum C channel pieces I'm using on print bed

ch_inside=19.1;
ch_wall=1.7;
ch_deep=13;

module channel_wall(length = 30, extra = 0) {
   ir=1.5;
   union() {
      // one wall of the channel
      cube([length, ch_wall+extra, ch_deep+extra+ch_wall+extra]);
      // round top of the wall
      translate([0,(ch_wall+extra)/2,ch_deep+extra+ch_wall+extra])
         rotate([0,90,0])
            cylinder(h=length,r=(ch_wall+extra)/2, $fn=32);
      // round inner base of wall where it joins bottom of channel
      difference() {
         cube([length, ch_wall+extra+ir, ch_wall+extra+ir]);
         translate([-1,ch_wall+extra+ir,ch_wall+extra+ir])
            rotate([0,90,0])
               cylinder(h=length+2,r=ir,$fn=32);
      }
   }
}

module channel (length = 30, extra = 0) {
   union() {
      // the bottom of the channel
      cube([length, ch_inside + 2*(ch_wall + extra), ch_wall+extra]);
      // one wall
      channel_wall(length,extra);
      // other wall
      translate([0,ch_inside + 2*(ch_wall + extra),0])
         mirror([0,1,0])
            channel_wall(length,extra);
   }
}

module bed_relief (length = 30, extra = 0) {
   screwdia=5;
   th=4;
   tothigh=((ch_wall+extra)/2)+th+ch_deep+extra+ch_wall+extra;
   totx=length;
   toty=(th*2)+ch_inside + 2*(ch_wall + extra);
   translate([0,0,tothigh])
      mirror([0,0,1])
         difference() {
            union() {
               cube([totx,toty,tothigh]);
               translate([0,-4,(tothigh-4)])
                  cube([totx,toty+8,4]);
            }
            translate([-1,th,-0.01])
               channel(length+2,extra);
            translate([2,-3,10])
               cube([totx-4,2,20]);
            translate([2,toty+1,10])
               cube([totx-4,2,20]);
         }
}

bed_relief(length=25, extra=0.2);
