// Now that I'm running Repetier-Server and mjpg-streamer I can watch
// the print remotely with a webcam, I got a nice small one (Logitech C920S)
// and these parts are designed to hang a camera mount on the front
// of the printer I can easily remove when I need to get access, or
// put back when I want to leave while it is printing.

// Some rod holders that wedge themselves into the top T slot
// seem to be the way to go, then a platform that mounts lower
// down on the rods with a hole for a 1/4-20 mounting screw.

// Just for preview, I don't know for sure what rod I want to use
// yet.
//
rodia=7.4+0.3;

// Also just for preview, need to cut out some cardboard or something
// and see what angle I really need.
rodang=30;

// Extracted this bit from the tslot-insert code. Printed a small test
// and I really can rotate it into place under the top lip of the tslot,
// so it is a starting place.
module inner_tslot(high=20) {
   linear_extrude(height=high)
   projection(cut=true)
   difference() {
      rotate([-90,0,0])
      translate([0,0,-2])
      difference() {
         translate([-10,-9,-4.01])
            cube([20,18,6.3]);
         difference() {
            translate([-10,-10,0])
               cube([20,20,2.3]);
            translate([-6.2/2,-22/2,-1])
               cube([6.2,22,4]);
         }
         translate([-10,-10,-6.3])
            cube([20,20,2]);
         translate([6.2/2,-10,-4])
            rotate([0,45,0])
               cube([20,20,20]);
         translate([-6.2/2,-10,-4])
            rotate([0,-45,0])
               translate([-20,0,0])
               cube([20,20,20]);
      }
      translate([-25,-25/2,-25/2])
         cube([25,25,25]);
      }
}

// Shape that nicely hooks under lip of t-slot and wraps around back of
// rail to be held in by gravity. Easily slides in and out by rotating it.
//
module hanger(high=20) {
   difference() {
      union() {
         difference() {
            // Start with basic t-slot shape
            inner_tslot(high);
            // trim a bit off the "nose" to allow some slack
            translate([6.6,-10,-1])
               cube([10,10,high+2]);
            // Trim off bottom corner to make it easier to get in and out
            translate([5,-10,-1])
               rotate([0,0,45])
                  translate([-10,0,0])
                     cube([10,10,high+2]);
         }
         // add top piece to sit on rail
         translate([-(10+4),0,0])
            cube([3.1+10+4,5,high]);
         // add "bump" to prevent sliding backwards off rail
         translate([(0.7+(2.5/2))-3.1,0,0])
            cylinder(r=2.5/2,h=high,$fn=64);
         // add back piece to wrap down over back of rail
         translate([-(10+4),-5.8,0])
            cube([3.8,6,high]);
      }   
      // Cut little notch on back of bump to allow everything to sit flat
      // on top of rail and counteract the tendency of printer to round edges
      // when printing.
      translate([-3.6,-5.7,-1])
         cube([1.3,6,high+2]);
   }
}

// Little piece to clamp rod with an M3 screw (should be plenty strong
// enough for the light webcam).
//
module rodclamp(high=20) {
   thick=3+2+2;
   wall=2;
   translate([-12,4,0])
   rotate([0,0,-(90-rodang)])
   union() {
      translate([0,thick/2,high+2*wall+(rodia/2)])
      rotate([90,0,0])
      difference() {
         union() {
            // outer cylinder of clamp
            cylinder(r=wall+(rodia/2),h=thick,$fn=64);
            // cube for clamp structure
            translate([-(0.5+2*wall)/2, -(((4*wall+rodia)/2)+high),0])
               cube([0.5+2*wall,high+6*wall+rodia,thick]);
         }
         // cut hole for rod
         translate([0,0,-1])
            cylinder(r=rodia/2,h=thick+2,$fn=64);
         // cut slot to allow M3 screw to clamp down on rod
         translate([-0.5/2,-((rodia/2)+wall+1),-1])
            cube([0.5,6*wall+rodia,thick+2]);
         // cut out bit at top to make overhang more likely to print well.
         translate([0,1,-1])
            rotate([0,0,45])
               cube([3,3,thick+2]);
         // cut hole for M3 bolt
         translate([-5,rodia/2+wall+3,thick/2])
            rotate([0,90,0])
               cylinder(r=3.3/2,h=10,$fn=64);
      }
      cylinder(r=6,h=high,$fn=64);
   }
}

// TODO: Figure out angle to hold rods and best way to attach them
// to hanger (and what rods to use - doweling or the metal things
// leftover from disassembly of CD holder). Do I want to be able to
// adjust the angle? (Semms like overkill).

// Proof of concept - figure out real angles and sizes...

module top_rail_mount(high=20) {
   union() {
      hanger(high);
      // Look at top view and make sure rod clamp doesn't intersect with the
      // rail when this gets mounted (yes, could do trig, but easier to eyeball
      // it).
      translate([0,2.2,0])
      rodclamp(high);
   }
}

// OK, some kludgery with cardboard and I think the camera should be 50mm
// below the center of the rodclamp. The platform the camera is bolted to
// should be 45mm wide.

module camera_arm(wide, wall) {
   difference() {
      union() {
         cube([wall,50,wide]);
         translate([4-(rodia+4),50-18,0])
            cube([rodia+4,30,wide]);
      }
      translate([(-rodia/2)+2,50,wide/2])
         rotate([rodang,0,0])
            translate([0,0,-25])
               union() {
                  cylinder(r=rodia/2,h=50,$fn=64);
                  translate([-0.75/2,(-60)+(rodia/2)+2,0])
                     cube([0.75,60,50]);
               }
      translate([-10,38,8])
         rotate([0,90,0])
            cylinder(r=3.3/2,h=20,$fn=64);
   }
}

module camera_platform() {
   wall=4;
   wide=20;
   union() {
      difference() {
         // platform for camera
         cube([45+2*wall,wall,wide]);
         // hole for 1/4-20 mounting bolt
         translate([(45+2*wall)/2,wall+1,wide/2])
            rotate([90,0,0])
               cylinder(r=0.2+(6.35/2), h=wall+2, $fn=64);
      }
      // side walls
      camera_arm(wide, wall);
      translate([45+2*wall,0,0])
         mirror([1,0,0])
            camera_arm(wide, wall);
   }
}

module new_platform() {
   difference() {
      hull() {
         translate([0,-25,0])
            cylinder(r=10,h=5,$fn=64);
         translate([0,25,0])
            cylinder(r=10,h=5,$fn=64);
      }
      translate([0,0,-1])
         cylinder(r=(0.25*25.4)/2,h=10,$fn=64);
   }
}

// The first one of these I printed was 44mm too high (despite how carefully
// I thought I measured everything), so after mounting the camera on a long
// screw and getting it where I wanted it, I measured the excess length of
// screw I needed and got 44mm, so print again with 44 subtracted from
// platform_below.
//
module camera_cantelever(thick=20) {
   wall=10;
   platform_below=(20+170+30)-44;
   union() {
      difference() {
         resize([(50+wall)*2,(platform_below+wall)*2,thick])
            cylinder(r=platform_below+wall,h=thick,$fn=64);
         translate([0,0,-1])
            resize([50*2,platform_below*2,thick+2])
               cylinder(r=platform_below,h=thick+2,$fn=64);
         translate([-(2*(50+wall+2))/2,-(platform_below+wall+2),-1])
            cube([2*(50+wall+2),platform_below+wall+2,thick+2]);
         translate([0,-1,-1])
            cube([2*(50+wall+2),platform_below+wall+2,thick+2]);
      }
      translate([-55,0,-25])
         rotate([-90,0,0])
            new_platform();
   }
}

module new_camera_mount(thick=20) {
   wall=10;
   platform_below=(20+170+30)-44;
   translate([0,0,thick])
   rotate([0,180,0])
   union() {
      translate([0,-(4.5+platform_below),0])
         camera_cantelever(thick=thick);
      translate([10,0,0])
         hanger(high=thick);
   }
}
