// Not a part of the finished printer, just a guide to simplify
// drilling the holes for the printbed adjusting screws in the
// aluminum channel pieces that make up the structure of the bed.

// Some pieces designed to be clamped to the channels making up the
// print bed structure to serve as a drilling guide for the holes for
// the adjusting screws. The idea is to drill the holes in the
// printbed itself, then slide these pieces as well as the channels
// around so the screws go precisely into the holes in these pieces,
// then clamp them in place and use them as a guide to drill holes
// in the channels so the holes in the bed place will exactly match.

// Dimensions for aluminum C channel pieces I'm using on print bed

ch_inside=19.1;
ch_wall=1.7;
ch_deep=13;

module channel_wall(length = 30, extra = 0) {
   ir=1.5;
   union() {
      // one wall of the channel
      cube([length, ch_wall+extra, ch_deep+extra+ch_wall+extra]);
      // round top of the wall
      translate([0,(ch_wall+extra)/2,ch_deep+extra+ch_wall+extra])
         rotate([0,90,0])
            cylinder(h=length,r=(ch_wall+extra)/2, $fn=32);
      // round inner base of wall where it joins bottom of channel
      difference() {
         cube([length, ch_wall+extra+ir, ch_wall+extra+ir]);
         translate([-1,ch_wall+extra+ir,ch_wall+extra+ir])
            rotate([0,90,0])
               cylinder(h=length+2,r=ir,$fn=32);
      }
   }
}

module channel (length = 30, extra = 0) {
   union() {
      // the bottom of the channel
      cube([length, ch_inside + 2*(ch_wall + extra), ch_wall+extra]);
      // one wall
      channel_wall(length,extra);
      // other wall
      translate([0,ch_inside + 2*(ch_wall + extra),0])
         mirror([0,1,0])
            channel_wall(length,extra);
   }
}

module drill_guide (length = 30, extra = 0) {
   screwdia=5;
   th=2;
   tothigh=((ch_wall+extra)/2)+th+ch_deep+extra+ch_wall+extra;
   totx=length;
   toty=(th*2)+ch_inside + 2*(ch_wall + extra);
   translate([0,0,tothigh])
      mirror([0,0,1])
         difference() {
            cube([totx,toty,tothigh]);
            translate([-1,th,-0.01])
               channel(length+2,extra);
            translate([totx/2,toty/2,-1])
               cylinder(h=tothigh+2,r=extra+screwdia/2,$fn=32);
         }
}

drill_guide(length=25, extra=0.2);
