// Holder for little circuit board that has a gazillion fan headers to
// provide 12 volt always on power for fans (and anything else that needs
// 12 volts). I'm using a prototyping board I got from amazon, so these
// dimensions are specific to it.

include <box.scad>

// long dimension of the board (plus slop)
board_long=96.53+0.5;

// short dimension of the board (plus slop)
board_short=44.51+ 0.5;

// thickness of the board
board_thick=1.55;

// diameter of the mounting holes at the corners
hole_dia=2.2;

// measured the hole to hole separation of outer edges of hole on long board
// dimension, so center of holes should be a half hole diameter in from each
// edge.
long_hole_sep=94.8-hole_dia;

// similar for hole separation on short side of board.
short_hole_sep=41.48-hole_dia;

// length of my shortest M2 bolts from top of socket head to end of
// threads
bolt_tot_len=10;

// thickness of the bolt head (above the board when screwed down).
bolt_head_thick=2;

// Dimensions I used for the screws in my spice holders. I'll use the
// same screws for these.
//
screw_head_diameter=8.5;
screw_shaft_diameter=3.9;
screw_head_height=2.5;

// The screw hole to subtract off the cleat for printing
//
module screw_hole(
   head_dia=screw_head_diameter,
   shaft_dia=screw_shaft_diameter,
   head_height=screw_head_height,
   screw_len=30) {
   rotate([0,180,0])
      union() {
         cylinder(r1=(head_dia/2),
                  r2=(shaft_dia/2),
                  h=head_height,
                  $fn=32);
         cylinder(r=(shaft_dia/2),
                  h=screw_len,
                  $fn=32);
         translate([0,0,-(screw_len-0.01)])
            cylinder(r=(head_dia/2),
                     h=screw_len,
                     $fn=32);
      }
}

// trap for M2 nut to be subtracted from middle of board thickness
//
module m2_trap() {
   union() {
      hexnut(m2nut_flat+0.4, m2nut_thick*2);
      translate([0,-(m2nut_flat+0.4)/2,-m2nut_thick*2])
         cube([10,m2nut_flat+0.4,m2nut_thick*2]);
   }
}

module board_mount() {
   difference() {
      union() {
         // The grid plate is a pain to render, should probably just
         // have crossed a couple of 12mm wide bars intersecting on
         // the screw holes rather than filling in the whole plate.
         // If there is some reason I need to reprint this, I should
         // make the change.
         render() {
            grid_plate(board_long+6,board_short+4,4,1);
         }
         translate([-(board_long+6)/2,-(board_short+4)/2,0])
            cube([board_long+6,6,4]);
         translate([-(board_long+6)/2,((board_short+4)/2)-6,0])
            cube([board_long+6,6,4]);
         translate([-(board_long+6)/2,-(board_short+4)/2,0])
            cube([6,board_short+4,4]);
         translate([((board_long+6)/2)-6,-(board_short+4)/2,0])
            cube([6,board_short+4,4]);
         translate([-(long_hole_sep)/2,-(short_hole_sep/2),0])
           cylinder(r=(hole_dia+7)/2,h=9,$fn=64);
         translate([(long_hole_sep)/2,-(short_hole_sep/2),0])
           cylinder(r=(hole_dia+7)/2,h=9,$fn=64);
         translate([-(long_hole_sep)/2,(short_hole_sep/2),0])
           cylinder(r=(hole_dia+7)/2,h=9,$fn=64);
         translate([(long_hole_sep)/2,(short_hole_sep/2),0])
           cylinder(r=(hole_dia+7)/2,h=9,$fn=64);
         translate([board_long/3,0,0])
            cylinder(r=6,h=4,$fn=64);
         translate([-board_long/3,0,0])
            cylinder(r=6,h=4,$fn=64);
      }
      translate([-board_long/2,-board_short/2,9-board_thick])
         cube([board_long,board_short,board_thick+1]);
      translate([-(long_hole_sep)/2,-(short_hole_sep/2),-1])
         cylinder(r=2.4/2,h=11,$fn=64);
      translate([(long_hole_sep)/2,-(short_hole_sep/2),-1])
         cylinder(r=2.4/2,h=11,$fn=64);
      translate([-(long_hole_sep)/2,(short_hole_sep/2),-1])
         cylinder(r=2.4/2,h=11,$fn=64);
      translate([(long_hole_sep)/2,(short_hole_sep/2),-1])
         cylinder(r=2.4/2,h=11,$fn=64);
      translate([-(long_hole_sep)/2,-(short_hole_sep/2),6])
         rotate([0,0,180])
            m2_trap();
      translate([(long_hole_sep)/2,-(short_hole_sep/2),6])
         m2_trap();
      translate([-(long_hole_sep)/2,(short_hole_sep/2),6])
         rotate([0,0,180])
            m2_trap();
      translate([(long_hole_sep)/2,(short_hole_sep/2),6])
         m2_trap();
      translate([board_long/3,0,3.5])
         screw_hole();
      translate([-board_long/3,0,3.5])
         screw_hole();
   }
}

board_mount();
