// I could buy feet for the box, but where's the fun in that. These
// feet are designed to be two interlocking pieces that can be screwed down
// and capture some non-skid shelf liner to cover the actual foot

// A single triangular shape stick
//
module triangle(len=15,base=3,height=1.5) {
   // translate it into the positive x,y quarter plane
   translate([len,0,0])
      // rotate it over on its side
      rotate([0,-90,0])
         // extrude it for the given length
         linear_extrude(height=len) {
            // make a triangle with the given base and height
            polygon(points = [
                  [0,0],
                  [height,height],
                  [0,base]
               ]);
         }
}

// Several triangular sticks next to one another
//
module washboard(sep=3,num=3,len=15,height=1.5) {
   lo=0;
   hi=sep*(num-1);
   for (i = [lo : sep : hi]) {
      translate([0,i,0])
         triangle(len=len,base=sep,height=height);
   }
}

// The shape of the surface that will form the foot, two washboards
// with a half cylinder in the middle.
//
module footshape(sep=3,num=3,len=15,height=1.5,rad=5,thick=1,trim=0.2) {
   wash_y=sep*num;
   difference() {
      union() {
         difference() {
            union() {
               // A washboard shape to capture the non-skid lining
               washboard(sep,num,len,height);
               // A cylinder for the non-skid surface to be the actual foot
               translate([0,rad+wash_y,0])
                  rotate([0,90,0])
                     cylinder(r=rad,h=len,$fn=64);
               // And another washboard on the other side of the cylinder
               translate([0,(2*rad)+wash_y,0])
                  washboard(sep,num,len,height);
            }
            translate([-1,-1,-(rad+1)])
               cube([len+2,(rad*2)+(wash_y*2)+2,rad+1]);
         }
         translate([0,0,-thick])
            cube([len,(rad*2)+(wash_y*2),thick+0.01]);
      }
      if (trim > 0) {
         union() {
            translate([-1,-1,-(thick+1)])
               cube([len+2,trim+1,rad+thick+2]);
            translate([-1,(rad*2)+(wash_y*2)-trim,-(thick+1)])
               cube([len+2,trim+1,rad+thick+2]);
            translate([-1,-1,-(thick+1)])
               cube([trim+1,2+(rad*2)+(wash_y*2),rad+thick+2]);
            translate([len-trim,-1,-(thick+1)])
               cube([trim+1,2+(rad*2)+(wash_y*2),rad+thick+2]);
         }
      }
   }
}

// Probably should be parameters, but these are the 1/2 inch screws
// I'll be using to attach the feet. Just hard code them.
//
screw_head_diameter=8.5;
screw_shaft_diameter=3.9;
screw_head_height=2.5;


// The screw hole to subtract off the lockshape
//
module screw_hole(thick2=3.5) {
   translate([0,0,thick2])
   rotate([0,180,0])
   union() {
      cylinder(r1=(screw_head_diameter/2),
               r2=(screw_shaft_diameter/2),
               h=screw_head_height,
               $fn=32);
      cylinder(r=(screw_shaft_diameter/2),
               h=thick2*2,
               $fn=32);
      translate([0,0,-0.99])
         cylinder(r=(screw_head_diameter/2),
                  h=1,
                  $fn=32);
   }
}


// This piece fits over the foot and is screwed down to lock the non-skid
// surface in place.
//
module lockshape(sep=3,num=3,len=15,height=1.5,rad=5,thick1=1,
                 thick2=3.5,space=0.5) {
   ylen=(2*sep*num)+(2*rad);
   translate([len/2,0,thick2])
   rotate([0,180,0])
   difference() {
      translate([-5,-5,0])
         difference() {
            union() {
               cube([len+10,ylen+10,thick2]);
               translate([0,(ylen+10)/2,0])
                  cylinder(r=5,h=thick2,$fn=64);
               translate([len+10,(ylen+10)/2,0])
                  cylinder(r=5,h=thick2,$fn=64);
            }
            translate([0,(ylen+10)/2,0])
               screw_hole(thick2);
            translate([len+10,(ylen+10)/2,0])
               screw_hole(thick2);
        }
      translate([0,0,thick1+space])
         render() {
            footshape(sep,num,len,height,rad,thick1+space+1,0);
         }
   }
}

module bothfeet () {
   union() {
      translate([-15/2,-18,1])
         footshape();
      translate([0,18,0])
         lockshape();
   }
}
