// Handy utility for making hex nut shapes along with the dimensions
// of common nuts

m2nut_thick=1.50;
m2nut_flat=3.90;

m3nut_thick=2.47;
m3nut_flat=5.44;

m5nut_flat=7.85;
m5nut_thick=3.83;

// 1/4 - 20 nut (q20)
q20nut_flat=10.90;
q20nut_thick=5.54;

// M3 washer dimensions
M3_wash_thick=0.47;
M3_wash_dia=6.77;

// M5 washer dimensions
M5_wash_thick=0.94;
M5_wash_dia=9.84;

// Utility routine for making hex nut shape
module hexnut(flat, thick) {
   intersection_for ( i = [0,60,120]) {
      rotate([0,0,i])
         translate([-(2*flat)/2, -flat/2, -thick])
            cube([2*flat,flat,thick]);
   }
}

// Build a disk with a nut trap to use to adjust spring tension
//
// This newer version allows the nut, and two washers to be
// glued into the knob, making it much simpler to take the knob on and off
// as I had to do that frequently when first setting up the printer.
//
module tension_nut() {
   difference() {
      // main body of tension nut
      cylinder(r=22/2,h=1.5+m3nut_thick+M3_wash_thick+M5_wash_thick+1.5,$fn=64);
      // Combined shape of M3 nut, M3 washer, and M5 washer stacked up with a
      // 3mm hole punched through all of them.
      translate([0,0,1.5])
         union() {
            translate([0,0,m3nut_thick+0.1])
               hexnut(m3nut_flat+0.2,m3nut_thick+0.1);
            translate([0,0,m3nut_thick])
               cylinder(r=(M3_wash_dia+0.3)/2,h=M3_wash_thick+0.1,$fn=64);
            translate([0,0,m3nut_thick+M3_wash_thick])
               cylinder(r=(M5_wash_dia+0.3)/2,h=10*M5_wash_thick,$fn=64);
            translate([0,0,-25])
               cylinder(r=3.2/2,h=50,$fn=64);
         }
         // notch edges for poor mans knurling
         for ( i = [0 : 45 : 315] ) {
            rotate([0,0,i])
               translate([22/2-1.5,-3/2,-1])
                  cube([5,3,20]);
         }
   }
}

tension_nut();
