// New z-stop pieces to use now that the printbed runds on shafts.
// There are two parts to make it simpler to print relatively strong
// and not fool with supports.

include <hexnut.scad>
include <vslot20x20.scad>

// z_stop_adjuster bolts to the z_stop_base and holds an M5 nut where
// the screw will go to do fine adjustment of the Z zero level.
//
// Some dimensions of note:
//
// The edge of the little cylinder on the end of the switch is 6mm inside
// the vertical rail.
//
// The cylinder itself is 4.5mm wide.
//
// The switch is attached to a 3mm thick plate and the cylinder is 5mm
// wide (about the thickness of the switch).
//
// So I want the level adjust screw to be as close to directly under the
// middle of the switch as possible.
//
// I can slide the block back and forth on the printbed, but the adjusting
// screw needs to be close enough to the edge of the block that it will fit
// under the switch without hitting the vertical rail.
//
module z_stop_adjuster() {
   bolt_len=27;          // total length of M5 bolt I plan to use
   h=bolt_len+m5nut_thick+3;

   translate([0,0,17])
   rotate([0,90,0])
   difference() {
      union() {
         translate([1,-23,0])
            cube([16,20,3]);
         translate([1,-19,-1.49])
            cube([16,12,1.5]);
         difference() {
            translate([1,-3,3])
               rotate([-25,0,0])
                  translate([0,-18.5,-20])
                     cube([16,18.5,70]);
            translate([-25,-25,h])
               cube([50,50,50]);
            translate([-25,-25,-(50-2.99)])
               cube([50,50,50]);
            translate([-25,-(50+3+20),-25])
               cube([50,50,50]);
         }
      }
      translate([6+2.3,3,0]) {
         // 4mm hole running all the way through for nut driver if
         // it turns out to be necessary (it isn't :-)
         translate([0,0,-1])
            cylinder(r=4/2,h+2,$fn=64);
         // 5mm hole for bolt through top of nut trap
         translate([0,0,0])
            cylinder(r=5.2/2,h=h,$fn=64);
         // 11mm hole to make room for the wide bolt head
         translate([0,0,0])
            cylinder(r=11/2,h=bolt_len,$fn=64);
         // nut trap for M5 nut in top of adjuster
         translate([0,0,h+1]) // Don't think height is quite right, fix later
            hexnut(m5nut_flat+0.2,m5nut_thick+1);
      }
      // Subtract v-slot shape from base
      translate([-10,-13,-10])
         rotate([0,90,0])
            vslot20x20(40);
      // Subtract 3mm holes for bolting to z_stop_base
      translate([0,5.5-(3+10),3+2])
         rotate([0,90,0])
            cylinder(r=3.3/2,h=20,$fn=64);
      translate([0,-(3+10)-5.5,3+2])
         rotate([0,90,0])
            cylinder(r=3.3/2,h=20,$fn=64);
      // Subtract 5.5mm holes for head of M3 bolt to fit in (to get it
      // out of way so it won't collide with vertical rail).
      translate([0,5.5-(3+10),3+2])
         rotate([0,90,0])
            cylinder(r=5.5/2,h=1+3,$fn=64);
      translate([0,-(3+10)-5.5,3+2])
         rotate([0,90,0])
            cylinder(r=5.5/2,h=1+3,$fn=64);
   }
}

// z_stop_base bolts to the v-slot rail on the front of the printbed
// and the z_stop_adjuster bolts to it (too difficult to design
// a single part for this unless I just want to print a giant cube).
//
// Actually, maybe I can print a single part. I already print the
// adjuster on the side, no reason I couldn't add an extension
// to bolt onto the front of the ral is there? On the other hand, I already
// printed the first piece and glued in the M5 nut :-).
//
module z_stop_base() {
   translate([0,0,4])
   rotate([-90,0,0])
   difference() {
      union() {
         // primary shape to go against printbed v-slot
         cube([16,4,23]);
         // cube on back to subtract off v-slot shape from
         translate([0,-1.5,4])
            cube([16,4+1.5,12]);
         // extension on top to join to piece that screw holder will bolt to
         translate([0,0,20])
            cube([19,4,3]);
         // top for screw holes
         translate([16,-20,20])
            cube([3,24,10]);
         // What the heck, put a v-slot mate on top as well
         translate([16,-(12+4),20-1.5])
            cube([3,12,7+1.5]);
         // add a bit of extra strength where top and front join
         translate([16,0,20])
            rotate([-90,0,0])
               cylinder(r=3,h=4,$fn=64);
      }
      // subtract v-slot shape from back and top
      translate([-1,-10,10])
         rotate([0,90,0])
            vslot20x20(50);
      // subtract hole for mounting bolt on printbed
      translate([8,5,10])
         rotate([90,0,0])
            cylinder(r=5.2/2,h=10,$fn=64);
      // subtract holes for m3 bolts to bolt on screw holder
      translate([10,5.5-10,25])
         rotate([0,90,0])
            cylinder(r=3.3/2,h=10,$fn=64);
      translate([10,-(10+5.5),25])
         rotate([0,90,0])
            cylinder(r=3.3/2,h=10,$fn=64);
   }
}
