include <vslot20x20.scad>
include <hexnut.scad>

// PROBLEM - Printed one of these as a test, and the corners curl up a
// bit. Wouldn't hurt to re-level the bed before printing more as well. I
// did add strain relief.

// Models for the pieces I'll need to print to convert the printbed to
// be supported on shafts. After all the trouble I've had with wheels and
// v-slots, this may be extreme overkill, but I want the printbed to be
// rock solid and only move when the z screws turn.

m4_head=6.87;

// The bracket to bolt to the printbed which linear bearings will
// be attached to (but that's a different print). This is designed
// to be stiff and screw tightly to the v-slot rails on the front
// and back of the printbed. I'll need four of them for the four
// linear shafts I'm planning to use. (Two left and two right versions)
//
// Do I want to add holes for t-nuts along the top and bottom of the
// printbed rail, or is the support simply resting on the top and bottom
// good enough?
//
module bed_bracket(do_left = true) {
   bhigh=105;
   bthick=4;
   bwide=35;
   hextra=20;

   mirror([0,do_left?0:1,0])
   translate([0,0,bthick])
   rotate([0,90,0])
   difference() {
      union() {
         // the main vertical cube
         translate([0,-bwide/2,-bhigh/2])
            cube([bthick,bwide,bhigh]);
         // the horizontal crosspiece sticking out the side of the vertical cube
         translate([0,-bwide/2,-(20)/2])
            cube([bthick,bwide+hextra,20+bthick]);
         // extra 1.5mm on center of back to subtract v-slot shape from
         translate([-1.5,-bwide/2,-15/2])
            cube([1.5+bthick,bwide+hextra,15]);
         // support on horizontal extension sticking over v-slot
         translate([bthick,0,0,])
            rotate([0,-90,0])
               linear_extrude(20+bthick)
                  polygon(points=[[10,hextra+(bwide/2)],
                                  [10+bthick,hextra+(bwide/2)],
                                  [(105)/2,bwide/2],
                                  [(105)/2,(bwide/2)-1],
                                  [10,(bwide/2)-1]]);
         // support for back of vertical (also sticking over vslot)
         translate([-20,-bwide/2,10])
            cube([bthick+20,bwide,(bhigh/2)-10]);
         // lower back support, only 25mm wide to avoid colliding with
         // the printbed aluminum c-channel supports that stick out the
         // bottom
         translate([-20,-bwide/2,-(bhigh/2)])
            cube([bthick+20,25,(bhigh/2)-10]);
         // Additional support full width, but low enough to clear the
         // c-channel supports
         translate([-20,-bwide/2,-(bhigh/2)])
            cube([bthick+20,bwide,(bhigh/2)-(10+6)]);
      }
      // subtract v-slot shape from the 1.5mm cube on the back to leave
      // shape to fit nicely in the v-slot rail and not rattle around
      translate([-10,hextra+bwide/2,0])
         rotate([90,0,0])
            vslot20x20(bwide+hextra);
      // Subtract cube rotated to cut off the supports on the back at the
      // angle which runs from the base to the peak.
      translate([0,0,bhigh/2])
         rotate([0,atan(20/((bhigh/2)-(10+bthick))),0])
            translate([-100,-((bwide/2) + 5),-bhigh/2])
               cube([100,10+bwide+hextra,bhigh]);
      // Subtract same cube mirrored to cut the bottom part
      mirror([0,0,1])
      translate([0,0,bhigh/2])
         rotate([0,atan(20/((bhigh/2)-(10+bthick))),0])
            translate([-100,-((bwide/2) + 5),-bhigh/2])
               cube([100,10+bwide+hextra,bhigh]);
      // Subtract off the holes for the t-nuts. One directly in line
      // with the shaft, one out on the horizontal extension
      translate([-5,0,0])
         rotate([0,90,0])
            cylinder(r=(5.2)/2, h=12, $fn=64);
      translate([-5,((bwide/2)+hextra)-10,0])
         rotate([0,90,0])
            cylinder(r=(5.2)/2, h=12, $fn=64);
      // Holes for mounting the top linear bearing. Shift it up a bit
      // to make sure it clears the bolt head for screwing the bracket
      // to the printbed.
      translate([0,12,(bhigh/2)-11])
         union() {
            rotate([0,-90,0])
               cylinder(r=(m4_head+0.4)/2,h=50,$fn=64);
            translate([bthick+2,0,0])
               rotate([0,-90,0])
                  cylinder(r=4.3/2,h=10,$fn=64);
         }
      translate([0,-12,(bhigh/2)-11])
         union() {
            rotate([0,-90,0])
               cylinder(r=(m4_head+0.4)/2,h=50,$fn=64);
            translate([bthick+2,0,0])
               rotate([0,-90,0])
                  cylinder(r=4.3/2,h=10,$fn=64);
         }
      translate([0,12,(bhigh/2)-(11+21)])
         union() {
            rotate([0,-90,0])
               cylinder(r=(m4_head+0.4)/2,h=50,$fn=64);
            translate([bthick+2,0,0])
               rotate([0,-90,0])
                  cylinder(r=4.3/2,h=10,$fn=64);
         }
      translate([0,-12,(bhigh/2)-(11+21)])
         union() {
            rotate([0,-90,0])
               cylinder(r=(m4_head+0.4)/2,h=50,$fn=64);
            translate([bthick+2,0,0])
               rotate([0,-90,0])
                  cylinder(r=4.3/2,h=10,$fn=64);
         }
      // Holes for mounting the bottom linear bearing. Shift the bottom
      // bearing block down by the same amount both to clear the bolt head
      // and also clear m4 bolt from the c-channel holder
      translate([0,12,-((bhigh/2)-11)])
         union() {
            rotate([0,-90,0])
               cylinder(r=(m4_head+0.4)/2,h=50,$fn=64);
            translate([bthick+2,0,0])
               rotate([0,-90,0])
                  cylinder(r=4.3/2,h=10,$fn=64);
         }
      translate([0,-12,-((bhigh/2)-11)])
         union() {
            rotate([0,-90,0])
               cylinder(r=(m4_head+0.4)/2,h=50,$fn=64);
            translate([bthick+2,0,0])
               rotate([0,-90,0])
                  cylinder(r=4.3/2,h=10,$fn=64);
         }
      translate([0,12,-((bhigh/2)-(11+21))])
         union() {
            rotate([0,-90,0])
               cylinder(r=(m4_head+0.4)/2,h=50,$fn=64);
            translate([bthick+2,0,0])
               rotate([0,-90,0])
                  cylinder(r=4.3/2,h=10,$fn=64);
         }
      translate([0,-12,-((bhigh/2)-(11+21))])
         union() {
            rotate([0,-90,0])
               cylinder(r=(m4_head+0.4)/2,h=50,$fn=64);
            translate([bthick+2,0,0])
               rotate([0,-90,0])
                  cylinder(r=4.3/2,h=10,$fn=64);
         }
      // Grooves for strain relief to make the print less likely
      // to curl up
      translate([bthick,0,-(bhigh+2)/2])
         cylinder(r=3/2,h=bhigh+2,$fn=64);
      translate([bthick,1.5+bwide/2,-(bhigh+2)/2])
         cylinder(r=3/2,h=bhigh+2,$fn=64);
      translate([bthick,(bwide/2)+hextra+1,(bhigh/2)-(11+21/2)])
         rotate([90,0,0])
            cylinder(r=3/2,h=bwide+hextra+2,$fn=64);
      translate([bthick,(bwide/2)+hextra+1,-((bhigh/2)-(11+21/2))])
         rotate([90,0,0])
            cylinder(r=3/2,h=bwide+hextra+2,$fn=64);
      // And some big holes as well
      translate([-21,0,(bhigh/2)-(11+21/2)])
         rotate([0,90,0])
            cylinder(r=8,h=20+bthick+2,$fn=64);
      translate([-21,0,-((bhigh/2)-(11+21/2))])
         rotate([0,90,0])
            cylinder(r=8,h=20+bthick+2,$fn=64);
      translate([-21,26,22])
         rotate([15,0,0])
            scale([1,0.6,1])
               rotate([0,90,0])
                  cylinder(r=6,h=20+bthick+2,$fn=64);
   }
}

// Utility I can use to print upside down nut traps with a shallow cone
// transition to hopefully prevent it from trying to print in open space
// and drooling bits of filament into the holes.
//
module upside_down_nut() {
   union() {
      translate([0,0,-2])
         cylinder(r=4.3/2,h=60,$fn=64);
      hexnut(m4nut_flat+0.3,10);
      translate([0,0,-0.01])
         cylinder(r1=m4nut_flat/2,r2=4.3/2,h=2,$fn=64);
   }
}

// Block for holding the linear bearing (blocks will be screwed to the
// bracket). do_top true generates the top half, false generates the bottom
// half. Each bracket needs two of each top and bottom halfs.  I'll need a
// total of 8 complete blocks for two bearings on each of four shafts.
//
module bearing_block(do_top = true) {
   // rotate part into printable position depending on which half
   // I'm printing.
   rotate([0,do_top?90:-90,0])
   difference() {
      // main cube shape of the bearing block
      translate([-((15/2)+1),-35/2,-2])
         cube([15+1+3,35,45+2+2]);
      // subtract 15x45mm hole for the linear bearing and 10mm hole
      // all the way through to leave a lip to hold the bearing and a
      // hole for the shaft.
      union() {
         cylinder(r=15/2,h=45,$fn=64);
         translate([0,0,-(60-45)/2])
            cylinder(r=10/2,h=60,$fn=64);
      }
      // subtract 4 holes for bolts and also sink shallow nut traps in the
      // top. Hole spacing identical to the bed bracket so they can be
      // bolted on.
      translate([1.5+(15/2),12,12])
         rotate([0,-90,0])
            upside_down_nut();
      translate([1.5+(15/2),-12,12])
         rotate([0,-90,0])
            upside_down_nut();
      translate([1.5+(15/2),12,33])
         rotate([0,-90,0])
            upside_down_nut();
      translate([1.5+(15/2),-12,33])
         rotate([0,-90,0])
            upside_down_nut();
      // subtract big hole from middle for strain relief
      translate([-25,0,45/2])
         rotate([0,90,0])
            cylinder(r=8,h=50,$fn=64);
      // subtract off either front or back half of whole block depending
      // on what I want to print.
      if (do_top) {
         translate([-40,-20,-4])
            cube([40,40,80]);
      } else {
         translate([0,-20,-4])
            cube([40,40,80]);
      }
   }
}

module nut_wart() {
   difference() {
      cylinder(r1=(m4nut_flat+3.15)/2, r2=(m4nut_flat+2.2)/2, h=1.8, $fn=64);
      translate([0,0,5])
         rotate([0,0,30])
         hexnut(m4nut_flat+0.3, 10);
   }
}

// Screw these to t-nuts in the top and bottom rails to provide a place
// to clamp the ends of the vertical shafts. The bottom and top rails are
// t-slots, so make the part that mates with the rail a cube slightly
// less than 6mm.
//
module shaft_clamp (do_left=true) {
   // Determine this number by measurement, this is just a guess.
   // (the distance from the front of the rail to the center of
   // the shaft).
   shaft_center=4+1+(15/2);
   wall=4;
   rad=wall+(8/2);
   
   mirror([do_left?0:1,0,0])
   difference() {
      union() {
         // outer cylinder wrapped around shaft
         translate([0,shaft_center,0])
            cylinder(r=rad,h=20,$fn=64);
         // cube running through cylinder out from rail
         translate([-wall,0,0])
            cube([2*wall,shaft_center+rad+10,20]);
         // back wall that sits against rail
         translate([-(2*rad+20)/2,0,0])
            cube([2*rad+20,wall,20]);
         // extension of back wall to fit into t-slot opening (I'll see
         // if this prints OK, may have to slope the bottom to avoid
         // trying to print in space - yep, needs the slope)).
         difference() {
            translate([-(2*rad+20)/2,-1.5,(20-(6-0.3))/2])
               cube([2*rad+20,wall+1.5,6-0.3]);
            translate([0,0,(20-(6-0.3))/2])
               rotate([60,0,0])
                  translate([-25,-50,0])
                     cube([50,50,50]);
         }
         // "wart" stuck on outside of clamp to hold nut and make it
         // easier to tighten
         translate([wall-0.01,shaft_center+rad+5,5.5])
            rotate([0,90,0])
               nut_wart();
         translate([wall-0.01,shaft_center+rad+5,20-5.5])
            rotate([0,90,0])
               nut_wart();
      }
      // hole for 8mm shaft
      translate([0,shaft_center,-1])
         cylinder(r=8.2/2,h=22,$fn=64);
      // slot to allow clamping down on shaft
      translate([-0.5,shaft_center-6,-1])
         cube([1,shaft_center+rad+10,22]);
      // holes for M4 bolts to do the clamping
      translate([-(2+(2*wall))/2,shaft_center+rad+5,5.5])
         rotate([0,90,0])
            cylinder(r=4.3/2,h=2+(2*wall),$fn=64);
      translate([-(2+(2*wall))/2,shaft_center+rad+5,20-5.5])
         rotate([0,90,0])
            cylinder(r=4.3/2,h=2+(2*wall),$fn=64);
      // subtract holes for bolts to attach to rail
      translate([((2*rad+20)/2)-5,wall+1,10])
         rotate([90,0,0])
            cylinder(r=5.2/2,h=10,$fn=64);
      translate([-(((2*rad+20)/2)-5),wall+1,10])
         rotate([90,0,0])
            cylinder(r=5.2/2,h=10,$fn=64);
   }
}
