// A little bracket with bumps that engage the holes in the X carriage
// so it can be clipped securely in place. It holds a microswitch facing down
// to use as a zprobe.
//
// If it won't clear the hotend after everything is installed, I guess I'll
// need to make "extra" longer than 25.
//
// The idea is to clip this on the carriage with binder clips and use
// G30 to report the movement of Z at various X,Y positions. Then adjust
// the set screws on the bed till the G30 report is identical everywhere
// on the bed, at which point you know it is level
//
// Since it is only attached when doing bed leveling, you'll want to configure
// the switch to be normally open.

include <carriages.scad>

module zswitch() {
   difference() {
      union() {
         cube([3,20,0+23.1]);
         translate([0,0,0+23])
            cube([3,20,20]);
      }

      translate([-3,7.8,5])
         rotate([0,90,0])
            rotate([0,0,90])
               rounded_slot(3,2.6,10);

      translate([-3,7.8,15])
         rotate([0,90,0])
            rotate([0,0,90])
               rounded_slot(3,2.6,10);
   }
}

module zprobe_mount() {
   extra=25;
   xh=wheel_thick+(2*wheel_spacer)+2*(plate_thick+3+10);
   wide=11.3;
   fy=3;
   ly=3+5;
   fz=(xh/2)-5;
   lz=fz-5;
   rotate([0,-90,0])
      union() {
         translate([0,0,-xh/2])
            cube([plate_thick,wide,xh+extra]);
         for (i = [fy : 5 : ly]) {
            for (j = [fz : -5: lz]) {
               translate([plate_thick-0.1,i,j])
                  rotate([0,90,0])
                     cylinder(r1=(2.9/2),r2=1,h=plate_thick-1,$fn=64);
               translate([plate_thick-0.1,i,-j])
                  rotate([0,90,0])
                     cylinder(r1=(2.9/2),r2=1,h=plate_thick-1,$fn=64);
            }
         }

         translate([0,43,xh/2+extra])
         mirror([0,1,0])
         rotate([-90,0,0])
         zswitch();
      }
}

zprobe_mount();
